@@ -8,6 +8,7 @@ from .discovery.crm.discovery import Discovery as CrmDiscovery
 from .discovery.events.discovery import Discovery as EventsDiscovery
 from .discovery.files.discovery import Discovery as FilesDiscovery
 from .discovery.marketing.discovery import Discovery as MarketingDiscovery
+from .discovery.settings.discovery import Discovery as SettingsDiscovery
 from .discovery.webhooks.discovery import Discovery as WebhooksDiscovery
 
 
@@ -79,6 +80,10 @@ class Client:
     def marketing(self):
         return MarketingDiscovery(self.config)
 
+    @property
+    def settings(self):
+        return SettingsDiscovery(self.config)
+
     @property
     def webhooks(self):
         return WebhooksDiscovery(self.config)
