@@ -18,3 +18,7 @@ class Discovery(DiscoveryBase):
     @property
     def batch_api(self) -> api_client.BatchApi:
         return self._configure_api_client(api_client, "BatchApi")
+
+    @property
+    def public_object_api(self) -> api_client.PublicObjectApi:
+        return self._configure_api_client(api_client, "PublicObjectApi")
